Rename LessPrivateGlobalPrefix -> LinkerPrivateGlobalPrefix to match the
LLVM IR concept.



git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@76590 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/DarwinTargetAsmInfo.cpp b/lib/Target/DarwinTargetAsmInfo.cpp
index 6540edd..31c29a7 100644
--- a/lib/Target/DarwinTargetAsmInfo.cpp
+++ b/lib/Target/DarwinTargetAsmInfo.cpp
@@ -57,7 +57,7 @@
   // Syntax:
   GlobalPrefix = "_";
   PrivateGlobalPrefix = "L";
-  LessPrivateGlobalPrefix = "l";  // Marker for some ObjC metadata
+  LinkerPrivateGlobalPrefix = "l";  // Marker for some ObjC metadata
   NeedsSet = true;
   NeedsIndirectEncoding = true;
   AllowQuotesInName = true;
@@ -105,17 +105,18 @@
 }
 
 /// emitUsedDirectiveFor - On Darwin, internally linked data beginning with
 /// the PrivateGlobalPrefix or the LessPrivateGlobalPrefix does not have the
 /// directive emitted (this occurs in ObjC metadata).
 bool DarwinTargetAsmInfo::emitUsedDirectiveFor(const GlobalValue* GV,
                                                Mangler *Mang) const {
   if (!GV) return false;
   
   // Check whether the mangled name has the "Private" or "LessPrivate" prefix.
   if (GV->hasLocalLinkage() && !isa<Function>(GV)) {
     const std::string &Name = Mang->getMangledName(GV);
+    // FIXME: Always "L" and "l", simplify!
     const char *PGPrefix = getPrivateGlobalPrefix();
-    const char *LPGPrefix = getLessPrivateGlobalPrefix();
+    const char *LPGPrefix = getLinkerPrivateGlobalPrefix();
     unsigned PGPLen = strlen(PGPrefix);
     unsigned LPGPLen = strlen(LPGPrefix);
@@ -105,17 +105,18 @@
 
 /// emitUsedDirectiveFor - On Darwin, internally linked data beginning with
-/// the PrivateGlobalPrefix or the LessPrivateGlobalPrefix does not have the
+/// the PrivateGlobalPrefix or the LinkerPrivateGlobalPrefix does not have the
 /// directive emitted (this occurs in ObjC metadata).
 bool DarwinTargetAsmInfo::emitUsedDirectiveFor(const GlobalValue* GV,
@@ -105,17 +105,18 @@
   if (!GV) return false;
   
-  // Check whether the mangled name has the "Private" or "LessPrivate" prefix.
+  // Check whether the mangled name has the "Private" or "LinkerPrivate" prefix.
   if (GV->hasLocalLinkage() && !isa<Function>(GV)) {
     const std::string &Name = Mang->getMangledName(GV);